@@ -166,7 +166,11 @@ def fleet_create(request):
 @permission_required("aapayout.basic_access")
 def fleet_detail(request, pk):
     """View fleet details"""
+    # Alliance Auth
+    from esi.models import Token
+
     # AA Payout
+    from aapayout import app_settings
     from aapayout.helpers import get_main_character_for_participant
 
     fleet = get_object_or_404(
@@ -187,19 +191,88 @@ def fleet_detail(request, pk):
             participant.save()
         updated_participants.append(participant)
 
+    # Deduplicate participants for display (group by main character)
+    from aapayout.helpers import deduplicate_participants
+
+    participant_groups = deduplicate_participants(updated_participants)
+
     # Get loot pools
     loot_pools = fleet.loot_pools.all().order_by("-created_at")
 
     # Calculate totals
     total_loot_value = fleet.get_total_loot_value()
 
+    # Calculate payout amounts for inline display (payouts auto-created after valuation)
+    payout_map = {}  # Maps main_character.id to payout amount
+    existing_payouts = {}  # Maps recipient.id to Payout instance (for status tracking)
+    if loot_pools.exists():
+        loot_pool = loot_pools.first()
+
+        # Payouts are automatically created when loot is valued (no approval step)
+        if loot_pool.status in [constants.LOOT_STATUS_APPROVED, constants.LOOT_STATUS_PAID]:
+            for payout in loot_pool.payouts.all():
+                existing_payouts[payout.recipient.id] = payout
+                payout_map[payout.recipient.id] = payout.amount
+
+    # Check ESI fleet import status (Phase 2)
+    # CRITICAL: Token must belong to the specific FC character, not just any character
+    esi_status = {
+        "enabled": app_settings.AAPAYOUT_ESI_FLEET_IMPORT_ENABLED,
+        "has_scope": False,
+        "can_import": False,
+        "message": None,
+        "fc_character_id": None,
+        "fc_character_name": None,
+    }
+
+    if esi_status["enabled"] and fleet.can_edit(request.user):
+        # Get FC character ID from session or use main character
+        fc_character_id = request.session.get("fc_character_id")
+        fc_character_name = request.session.get("fc_character_name", "Unknown")
+
+        if not fc_character_id:
+            # Fall back to main character
+            fc_character = request.user.profile.main_character if hasattr(request.user, "profile") else None
+            if fc_character:
+                fc_character_id = fc_character.character_id
+                fc_character_name = fc_character.character_name
+            else:
+                esi_status["message"] = "Select FC character from dropdown above"
+                fc_character_id = None
+
+        esi_status["fc_character_id"] = fc_character_id
+        esi_status["fc_character_name"] = fc_character_name
+
+        if fc_character_id:
+            # CRITICAL: Check if user has valid token for THIS specific character
+            token = (
+                Token.objects.filter(
+                    user=request.user,
+                    character_id=fc_character_id,  # Must match exactly!
+                )
+                .require_scopes("esi-fleets.read_fleet.v1")
+                .require_valid()
+                .first()
+            )
+
+            if token:
+                esi_status["has_scope"] = True
+                esi_status["can_import"] = True
+            else:
+                esi_status["has_scope"] = False
+                esi_status["message"] = f"ESI token required for {fc_character_name}"
+
     context = {
         "fleet": fleet,
         "participants": updated_participants,
+        "participant_groups": participant_groups,  # Deduplicated groups for display
         "loot_pools": loot_pools,
         "total_loot_value": total_loot_value,
         "can_edit": fleet.can_edit(request.user),
         "can_delete": fleet.can_delete(request.user),
+        "esi_status": esi_status,
+        "payout_map": payout_map,
+        "existing_payouts": existing_payouts,
     }
 
     return render(request, "aapayout/fleet_detail.html", context)
@@ -266,41 +339,50 @@ def participant_add(request, fleet_id):
 
     if request.method == "POST":
         form = ParticipantAddForm(request.POST)
-        if form.is_valid():
-            # Get character by name
-            character_name = form.cleaned_data["character_name"]
-            try:
-                # Filter by category name "character" (EveEntity uses ForeignKey to EveType)
-                character = EveEntity.objects.get(name=character_name, category__name="character")
-            except EveEntity.DoesNotExist:
-                messages.error(request, f"Character '{character_name}' not found")
-                return render(
-                    request,
-                    "aapayout/participant_add.html",
-                    {
-                        "form": form,
-                        "fleet": fleet,
-                    },
-                )
-
-            # Check if already a participant
-            if FleetParticipant.objects.filter(fleet=fleet, character=character).exists():
-                messages.warning(request, f"{character.name} is already in this fleet")
-                return redirect("aapayout:fleet_detail", pk=fleet.pk)
-
-            # Create participant
-            participant = form.save(commit=False)
-            participant.fleet = fleet
-            participant.character = character
-            participant.save()
-
-            messages.success(request, f"Added {character.name} to the fleet")
+        if not form.is_valid():
+            # Form validation errors - show error and redirect back
+            for field, errors in form.errors.items():
+                for error in errors:
+                    messages.error(request, f"{field}: {error}")
             return redirect("aapayout:fleet_detail", pk=fleet.pk)
-    else:
-        form = ParticipantAddForm()
 
-    context = {"form": form, "fleet": fleet}
-    return render(request, "aapayout/participant_add.html", context)
+        # Get character by name
+        character_name = form.cleaned_data["character_name"]
+        try:
+            # Filter by category (EveEntity.CATEGORY_CHARACTER constant)
+            character = EveEntity.objects.get(name=character_name, category=EveEntity.CATEGORY_CHARACTER)
+        except EveEntity.DoesNotExist:
+            messages.error(request, f"Character '{character_name}' not found")
+            return redirect("aapayout:fleet_detail", pk=fleet.pk)
+
+        # Check if already a participant
+        if FleetParticipant.objects.filter(fleet=fleet, character=character).exists():
+            messages.warning(request, f"{character.name} is already in this fleet")
+            return redirect("aapayout:fleet_detail", pk=fleet.pk)
+
+        # Create participant
+        participant = form.save(commit=False)
+        participant.fleet = fleet
+        participant.character = character
+        participant.save()
+
+        # Auto-recalculate payouts if loot exists
+        if fleet.loot_pools.exists():
+            loot_pool = fleet.loot_pools.first()
+            if loot_pool.status in [constants.LOOT_STATUS_APPROVED, constants.LOOT_STATUS_VALUED]:
+                # AA Payout
+                from aapayout.helpers import create_payouts
+
+                payouts_created = create_payouts(loot_pool)
+                logger.info(f"Auto-regenerated {payouts_created} payouts after adding participant")
+                if payouts_created > 0:
+                    messages.info(request, f"Payouts recalculated: {payouts_created} payouts updated")
+
+        messages.success(request, f"Added {character.name} to the fleet")
+        return redirect("aapayout:fleet_detail", pk=fleet.pk)
+
+    # GET request - redirect to fleet detail (modal is used instead)
+    return redirect("aapayout:fleet_detail", pk=fleet.pk)
 
 
 @login_required
@@ -343,6 +425,19 @@ def participant_remove(request, pk):
     character_name = participant.character.name
     participant.delete()
 
+    # Auto-recalculate payouts if loot exists
+    fleet = Fleet.objects.get(pk=fleet_pk)  # Re-fetch after delete
+    if fleet.loot_pools.exists():
+        loot_pool = fleet.loot_pools.first()
+        if loot_pool.status in [constants.LOOT_STATUS_APPROVED, constants.LOOT_STATUS_VALUED]:
+            # AA Payout
+            from aapayout.helpers import create_payouts
+
+            payouts_created = create_payouts(loot_pool)
+            logger.info(f"Auto-regenerated {payouts_created} payouts after removing participant")
+            if payouts_created > 0:
+                messages.info(request, f"Payouts recalculated: {payouts_created} payouts updated")
+
     messages.success(request, f"Removed {character_name} from the fleet")
     return redirect("aapayout:fleet_detail", pk=fleet_pk)
 
@@ -366,6 +461,11 @@ def loot_create(request, fleet_id):
         messages.error(request, "You don't have permission to edit this fleet")
         return redirect("aapayout:fleet_detail", pk=fleet.pk)
 
+    # Check if fleet already has a loot pool (only one allowed per fleet)
+    if fleet.loot_pools.exists():
+        messages.error(request, "This fleet already has a loot pool. Only one loot pool is allowed per fleet.")
+        return redirect("aapayout:fleet_detail", pk=fleet.pk)
+
     # Warn if Janice API key is not configured
     if not app_settings.AAPAYOUT_JANICE_API_KEY:
         messages.warning(
@@ -387,25 +487,26 @@ def loot_create(request, fleet_id):
             loot_pool.save()
             logger.info(f"Loot pool {loot_pool.id} saved to database")
 
-            # Trigger appraisal (async if Celery is available, sync otherwise)
-            try:
-                # Try async first
-                logger.info(f"Triggering async appraisal task for loot pool {loot_pool.id}")
-                task = appraise_loot_pool.delay(loot_pool.id)
-                logger.info(f"Celery task {task.id} queued for loot pool {loot_pool.id}")
-                messages.success(request, "Loot pool created! Valuation in progress, this may take a few moments...")
-            except Exception as e:
-                # If Celery isn't available, run synchronously
-                logger.warning(f"Celery not available, running appraisal synchronously: {e}")
-                result = appraise_loot_pool(loot_pool.id)
-                if result.get("success"):
-                    messages.success(request, "Loot pool created and valued successfully!")
-                else:
-                    messages.error(
-                        request, f"Loot pool created but valuation failed: {result.get('error', 'Unknown error')}"
-                    )
+            # Run appraisal synchronously
+            # The Janice API is fast enough that async processing is not needed,
+            # and sync provides immediate feedback to the user
+            logger.info(f"Running synchronous appraisal for loot pool {loot_pool.id}")
+            result = appraise_loot_pool(loot_pool.id)
 
-            return redirect("aapayout:loot_detail", pk=loot_pool.pk)
+            if result.get("success"):
+                messages.success(
+                    request,
+                    f"Loot pool created and valued successfully! "
+                    f"{result.get('items_created')} items valued at {result.get('total_value'):,.2f} ISK. "
+                    f"{result.get('payouts_created')} payouts created.",
+                )
+            else:
+                messages.error(
+                    request, f"Loot pool created but valuation failed: {result.get('error', 'Unknown error')}"
+                )
+                messages.info(request, "You can retry valuation from the loot pool detail page.")
+
+            return redirect("aapayout:fleet_detail", pk=fleet.pk)
         else:
             logger.warning(f"Loot pool form validation failed for fleet {fleet.id}: {form.errors}")
     else:
@@ -456,12 +557,12 @@ def loot_reappraise(request, pk):
         messages.success(
             request,
             f"Loot reappraised successfully! {result.get('items_created')} items valued at "
-            f"{result.get('total_value'):,.2f} ISK"
+            f"{result.get('total_value'):,.2f} ISK. {result.get('payouts_created')} payouts created.",
         )
     else:
         messages.error(request, f"Reappraisal failed: {result.get('error', 'Unknown error')}")
 
-    return redirect("aapayout:loot_detail", pk=loot_pool.pk)
+    return redirect("aapayout:fleet_detail", pk=loot_pool.fleet.pk)
 
 
 @login_required
@@ -582,6 +683,27 @@ def loot_approve(request, pk):
     return render(request, "aapayout/loot_approve.html", context)
 
 
+@login_required
+@permission_required("aapayout.basic_access")
+@require_POST
+def regenerate_payouts(request, pool_id):
+    """Manually regenerate payouts for a loot pool"""
+    # AA Payout
+    from aapayout.helpers import create_payouts
+
+    loot_pool = get_object_or_404(LootPool, pk=pool_id)
+
+    if not loot_pool.fleet.can_edit(request.user):
+        messages.error(request, "Permission denied")
+        return redirect("aapayout:fleet_detail", pk=loot_pool.fleet.pk)
+
+    payouts_created = create_payouts(loot_pool)
+    messages.success(request, f"Recalculated {payouts_created} payouts")
+    logger.info(f"Manual payout recalculation by {request.user.username}: {payouts_created} payouts")
+
+    return redirect("aapayout:fleet_detail", pk=loot_pool.fleet.pk)
+
+
 # ============================================================================
 # Payout Management
 # ============================================================================
@@ -682,9 +804,18 @@ def verify_payments(request, pool_id):
         # Alliance Auth
         from esi.models import Token
 
+        # Get FC's main character ID
+        fc_character = request.user.profile.main_character if hasattr(request.user, "profile") else None
+        if not fc_character:
+            messages.error(request, "You need to set a main character in your profile to verify payments.")
+            return redirect("aapayout:payout_list", pool_id=pool_id)
+
+        # Get token for the specific FC character
+        # IMPORTANT: ESI requires the token to match the character ID being queried
         token = (
             Token.objects.filter(
                 user=request.user,
+                character_id=fc_character.character_id,  # Token must match the FC character
             )
             .require_scopes("esi-wallet.read_character_journal.v1")
             .require_valid()
@@ -694,8 +825,8 @@ def verify_payments(request, pool_id):
         if not token:
             messages.error(
                 request,
-                "You need to link your ESI token with wallet journal access. "
-                "Please add the 'esi-wallet.read_character_journal.v1' scope.",
+                "You need to link your main character's ESI token with wallet journal access. "
+                "Please add the 'esi-wallet.read_character_journal.v1' scope for your main character.",
             )
             return redirect("aapayout:payout_list", pool_id=pool_id)
 
@@ -938,10 +1069,10 @@ def character_search(request):
     # Search for characters
     characters = EveEntity.objects.filter(
         name__icontains=query,
-        category__name="character",  # Characters only (category is ForeignKey)
+        category=EveEntity.CATEGORY_CHARACTER,  # Characters only
     ).order_by("name")[:20]
 
-    results = [{"id": char.id, "name": char.name} for char in characters]
+    results = [{"character_id": char.id, "character_name": char.name} for char in characters]
 
     return JsonResponse({"results": results})
 
@@ -976,11 +1107,23 @@ def participant_update_status(request, pk):
 
         participant.save()
 
+        # Auto-recalculate payouts if loot exists
+        payouts_recalculated = 0
+        if participant.fleet.loot_pools.exists():
+            loot_pool = participant.fleet.loot_pools.first()
+            if loot_pool.status in [constants.LOOT_STATUS_APPROVED, constants.LOOT_STATUS_VALUED]:
+                # AA Payout
+                from aapayout.helpers import create_payouts
+
+                payouts_recalculated = create_payouts(loot_pool)
+                logger.info(f"Auto-regenerated {payouts_recalculated} payouts after status update for participant {pk}")
+
         return JsonResponse(
             {
                 "success": True,
                 "is_scout": participant.is_scout,
                 "excluded_from_payout": participant.excluded_from_payout,
+                "payouts_recalculated": payouts_recalculated,
             }
         )
 
@@ -1027,11 +1170,28 @@ def fleet_import(request, pk):
         return redirect("aapayout:fleet_detail", pk=fleet.pk)
 
     if request.method == "POST":
-        # Get user's ESI token with required scope
+        # Get FC character ID from session or use main character
+        fc_character_id = request.session.get("fc_character_id")
+        fc_character_name = request.session.get("fc_character_name", "Unknown")
+
+        if not fc_character_id:
+            # Fall back to main character
+            fc_character = request.user.profile.main_character if hasattr(request.user, "profile") else None
+            if not fc_character:
+                messages.error(
+                    request, "Please select an FC character from the dropdown in the navigation bar before importing."
+                )
+                return redirect("aapayout:fleet_detail", pk=fleet.pk)
+            fc_character_id = fc_character.character_id
+            fc_character_name = fc_character.character_name
+
+        # Get ESI token for the specific FC character with required scope
+        # CRITICAL: ESI requires the token to match the character ID being queried
         try:
             token = (
                 Token.objects.filter(
                     user=request.user,
+                    character_id=fc_character_id,  # Token must match the FC character
                 )
                 .require_scopes("esi-fleets.read_fleet.v1")
                 .require_valid()
@@ -1041,54 +1201,69 @@ def fleet_import(request, pk):
             if not token:
                 messages.error(
                     request,
-                    "You need to add an ESI token with fleet read access. "
-                    "Please click 'Add/Update Character' below and authorize the 'esi-fleets.read_fleet.v1' scope.",
+                    f"No ESI token found for character '{fc_character_name}' (ID: {fc_character_id}). "
+                    f"Please add/update your ESI token for this specific character in Alliance Auth. "
+                    f"Go to: Services → EVE Online → Add/Update Character → Select '{fc_character_name}' → "
+                    f"Authorize with 'esi-fleets.read_fleet.v1' scope.",
                 )
-                return redirect("aapayout:fleet_import", pk=fleet.pk)
+                return redirect("aapayout:fleet_detail", pk=fleet.pk)
 
         except Exception as e:
-            logger.error(f"Failed to get ESI token for user {request.user.id}: {e}")
+            logger.error(f"Failed to get ESI token for character {fc_character_id}: {e}")
             messages.error(request, "Failed to get your ESI token. Please try adding your character again.")
-            return redirect("aapayout:fleet_import", pk=fleet.pk)
+            return redirect("aapayout:fleet_detail", pk=fleet.pk)
 
-        # Get FC character ID from session or use main character
-        fc_character_id = request.session.get("fc_character_id")
-
-        if not fc_character_id:
-            # Fall back to main character
-            fc_character = request.user.profile.main_character if hasattr(request.user, "profile") else None
-            if not fc_character:
-                messages.error(request, "Please select an FC character from the dropdown in the top navigation bar.")
-                return redirect("aapayout:fleet_import", pk=fleet.pk)
-            fc_character_id = fc_character.character_id
+        logger.info(f"Using ESI token for character {fc_character_id} ({fc_character_name})")
 
         # Get the fleet ID the FC is currently in
         logger.info(f"Checking if character {fc_character_id} is in a fleet")
-        esi_fleet_id = esi_fleet_service.get_character_fleet_id(fc_character_id, token)
+        esi_fleet_id, fleet_role, check_error = esi_fleet_service.get_character_fleet_id(fc_character_id, token)
 
-        if not esi_fleet_id:
+        if check_error or not esi_fleet_id:
+            error_msg = check_error or "You are not currently in a fleet in EVE Online."
+            messages.error(request, f"{error_msg} Please join a fleet and try again.")
+            return redirect("aapayout:fleet_detail", pk=fleet.pk)
+
+        # Validate fleet role - must be fleet commander to import members
+        if fleet_role != "fleet_commander":
             messages.error(
                 request,
-                "You are not currently in a fleet in EVE Online. " "Please join a fleet and try again.",
+                f"You must be the Fleet Commander (Fleet Boss) to import fleet members. "
+                f"Your current role is '{fleet_role}'. "
+                f"Please ask the FC to promote you to Fleet Boss or use their character to import.",
             )
-            return redirect("aapayout:fleet_import", pk=fleet.pk)
+            return redirect("aapayout:fleet_detail", pk=fleet.pk)
 
-        logger.info(f"FC is in fleet {esi_fleet_id}, importing members")
+        logger.info(f"FC is in fleet {esi_fleet_id} with role '{fleet_role}', importing members")
 
         # Import fleet composition from ESI
         member_data, error = esi_fleet_service.import_fleet_composition(esi_fleet_id, token)
 
         if error:
             messages.error(request, f"Failed to import fleet: {error}")
-            return redirect("aapayout:fleet_import", pk=fleet.pk)
+            return redirect("aapayout:fleet_detail", pk=fleet.pk)
 
         # Create ESI import record
+        # Convert member_data to JSON-serializable format
+        serializable_data = []
+        for member in member_data:
+            serializable_member = member.copy()
+            # Convert datetime to ISO format string
+            if "join_time" in serializable_member and serializable_member["join_time"]:
+                serializable_member["join_time"] = serializable_member["join_time"].isoformat()
+            # Convert EveEntity to character ID and name
+            if "character_entity" in serializable_member:
+                char_entity = serializable_member.pop("character_entity")
+                serializable_member["character_id"] = char_entity.id
+                serializable_member["character_name"] = char_entity.name
+            serializable_data.append(serializable_member)
+
         esi_import = ESIFleetImport.objects.create(
             fleet=fleet,
             esi_fleet_id=esi_fleet_id,
             imported_by=request.user,
             characters_found=len(member_data),
-            raw_data=member_data,  # Store raw data for debugging
+            raw_data=serializable_data,  # Store JSON-serializable data for debugging
         )
 
         # Process members and add as participants
@@ -1150,15 +1325,22 @@ def fleet_import(request, pk):
             f"Skipped {characters_skipped} already in fleet.",
         )
 
-        return redirect("aapayout:fleet_import_results", import_id=esi_import.pk)
+        # Auto-recalculate payouts if loot exists
+        if fleet.loot_pools.exists():
+            loot_pool = fleet.loot_pools.first()
+            if loot_pool.status in [constants.LOOT_STATUS_APPROVED, constants.LOOT_STATUS_VALUED]:
+                # AA Payout
+                from aapayout.helpers import create_payouts
 
-    # GET request - show import form
-    context = {
-        "fleet": fleet,
-        "recent_imports": fleet.esi_imports.all()[:5],
-    }
+                payouts_created = create_payouts(loot_pool)
+                logger.info(f"Auto-regenerated {payouts_created} payouts after ESI fleet import")
+                if payouts_created > 0:
+                    messages.info(request, f"Payouts recalculated: {payouts_created} payouts created/updated")
 
-    return render(request, "aapayout/fleet_import.html", context)
+        return redirect("aapayout:fleet_detail", pk=fleet.pk)
+
+    # GET request - redirect to fleet detail (import is now inline via POST button)
+    return redirect("aapayout:fleet_detail", pk=fleet.pk)
 
 
 @login_required
